noscrapy
========

Python port attempt of web-scraper-chrome-extension_.

|Build Status| |Coveralls| |Documentation Status| |Requirements Status|
|Downloads| |Latest Version| |Supported Python versions|
|Supported Python implementations| |Development Status| |Wheel Status|
|Egg Status| |Download format| |License|



.. _web-scraper-chrome-extension: https://github.com/martinsbalodis/web-scraper-chrome-extension
.. |Build Status| image:: https://travis-ci.org/katakumpo/noscrapy.svg
   :target: https://travis-ci.org/katakumpo/noscrapy
.. |Coveralls| image:: https://coveralls.io/repos/katakumpo/noscrapy/badge.png?branch=master
   :target: https://coveralls.io/r/katakumpo/noscrapy?branch=master
.. |Downloads| image:: https://pypip.in/download/noscrapy/badge.svg
   :target: https://pypi.python.org/pypi/noscrapy/
.. |Latest Version| image:: https://pypip.in/version/noscrapy/badge.svg
   :target: https://pypi.python.org/pypi/noscrapy/
.. |Supported Python versions| image:: https://pypip.in/py_versions/noscrapy/badge.svg
   :target: https://pypi.python.org/pypi/noscrapy/
.. |Supported Python implementations| image:: https://pypip.in/implementation/noscrapy/badge.svg
   :target: https://pypi.python.org/pypi/noscrapy/
.. |Development Status| image:: https://pypip.in/status/noscrapy/badge.svg
   :target: https://pypi.python.org/pypi/noscrapy/
.. |Wheel Status| image:: https://pypip.in/wheel/noscrapy/badge.svg
   :target: https://pypi.python.org/pypi/noscrapy/
.. |Egg Status| image:: https://pypip.in/egg/noscrapy/badge.svg
   :target: https://pypi.python.org/pypi/noscrapy/
.. |Download format| image:: https://pypip.in/format/noscrapy/badge.svg
   :target: https://pypi.python.org/pypi/noscrapy/
.. |License| image:: https://pypip.in/license/noscrapy/badge.svg
   :target: https://pypi.python.org/pypi/noscrapy/
.. |Documentation Status| image:: https://readthedocs.org/projects/noscrapy-py/badge/?version=latest
   :target: https://noscrapy-py.readthedocs.org/en/latest/
.. |Requirements Status| image:: https://requires.io/github/katakumpo/noscrapy/requirements.svg?branch=master
   :target: https://requires.io/github/katakumpo/noscrapy/requirements/?branch=master
